.. crypto-pandas documentation master file

Crypto-Pandas Documentation
===========================

.. mdinclude:: ../../README.md

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   examples
   about
   api/modules

.. _modules:
    Crypto-Pandas Modules Documentation
    ===================================
    
    .. toctree::
       :maxdepth: 2
    
    Module Summary
    --------------
    
    .. autosummary::
       :toctree: _autosummary
       :recursive:
       crypto_pandas
       crypto_pandas.utils

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
